@@ -5,6 +5,7 @@ from .offline_stores.postgres import (
 )
 from .offline_stores.postgres_source import PostgreSQLOptions, PostgreSQLSource
 from .online_stores.postgres import PostgreSQLOnlineStore, PostgreSQLOnlineStoreConfig
+from .registry_store import PostgreSQLRegistryStore
 
 __all__ = [
     "PostgreSQLOfflineStore",
@@ -14,4 +15,5 @@ __all__ = [
     "PostgreSQLSource",
     "PostgreSQLOnlineStore",
     "PostgreSQLOnlineStoreConfig",
+    "PostgreSQLRegistryStore",
 ]
